# BayernId

## Einleitung:

Der Antragsraum verwendet das Servicekonto im Bayerischen Portalverbund ( BayernId ) als Identity Provider und den
Zugriff zu ermöglichen und abzusichern.

Das Servicekonto im Bayerischen Portalverbund ( BayernId ) verwendet OASIS Security Assertion Markup Language (SAML)
V2.0)
https://docs.oasis-open.org/security/saml/v2.0/saml-core-2.0-os.pdf als Protokoll zur Authentifizierung des Benutzers.

## Voraussetzungen:

Damit der Antragsraum an die BayernId angeschlossen werden kann müssen SAML Metadaten erstellt werden und an
Akdb übermittelt werden
siehe [Dokumentation Servicekonto im Bayrischen Portalverbund v4.0](Das_Servicekonto_im_Bayerischen_Portalverbund_v4.0.pdf)

Dazu müssen zwei Zertifikate mit privaten Keys erstellt werden:

Beispiel:

```
openssl req -newkey rsa:2048 -nodes -keyout bayernid-test-enc.key -x509 -days 365 -out bayernid-test-enc.crt
openssl req -newkey rsa:2048 -nodes -keyout bayernid-test-sign.key -x509 -days 365 -out bayernid-test-sign.crt
```

Diese müssen dann in das [Metadaten Template](ozg-application-room-saml-metadata-template.xml) eingefügt werden.

Der Text zwischen den Markierungen "-----BEGIN CERTIFICATE-----" und "-----END CERTIFICATE-----" des Zertifikates
bayernid-test-sign.crt wird an der Stelle "<!-- signing certificate here -->" eingefügt.

Der Text zwischen den Markierungen "-----BEGIN CERTIFICATE-----" und "-----END CERTIFICATE-----" des Zertifikates
bayernid-test-enc.crt wird an der Stelle "<!-- encryption certificate here -->" eingefügt.

Es müssen auch weitere Informationen in das Template eingetragen werden:

* AssertionConsumerService Location. Das ist die öffentlich erreichbare Adresse des Spring SAML2 SSO Endpunkts des
  Antragraum-Backends. Ist für das Binding HTTP-POST und HTTP-Redirect gleich.
* ContactPerson contactType="technical": Hier muss die eMail Adresse des technischen Ansprechpartners eingetragen
  werden.
* ContactPerson contactType="support": Hier muss die eMail Adresse des fachlichen Ansprechpartners eingetragen
  werden.

Eingetragen sind schon die Werte:

* entityID: Ist schon eingetragen und lautet: https://antragsraum.ozgcloud.de/
* Organization: Hier ist mgm tp eingetragen

Es ist darauf zu achten, dass

1. die einzureichenden Metadaten kein Ablaufdatum enthalten ( validUntil-Attribut )
2. die Metadaten kein ID-Attribut enthalten,
3. die entityID als URI in URL-Notation mit https-Protokoll-Prefix ohne(!) Portnummer anzugeben ist. Diese muss nicht(!)
   zwingend mit der
   tatsächlich genutzten URL-Domain übereinstimmen, ist aber in Zusammenhang mit dem Attribut bPK in dieser Notation
   anzugeben. Die Auswahl
   der entityID kann nach Aufnahme in den Wirkbetrieb nicht(!) mehr verändert werden, und sollte daher den Betreiber der
   Drittanwendung eindeutig
   identifizieren (also nicht unspezifisch sein) wie folgendes
   Negativbeispiel (!) https://drittanwendung.com:1234/serviceprovider , sondern sprechend
   wie folgendes Vorbild https://dorf-enigmatting.de/online-rathaus

Die ausgefüllte Metadaten Datei muss dann an Adkb (BayernID@akdb.de) gesendet werden.
Siehe dazu 7. Betriebsvoraussetzungen in
der [Dokumentation Servicekonto im Bayrischen Portalverbund v4.0](Das_Servicekonto_im_Bayerischen_Portalverbund_v4.0.pdf)

## Ablauf

Der Ablauf des Logins über das BayernId Portals ist:

![Ablauf login](diagrams/SAML-login-sequence.png)

Wenn sich der Endkunde im Antragsraum anmeldet, erfolgt ein Aufruf des login-Endpunkts im Antragsraum-Backends.
Von dort wird er auf die Login-Seite des BayernId Portals weiter gleitet wo er sich Anmelden kann.

War die Anmeldung erfolgreich erfolgt eine Weiterleitung zum SAML SSO Login Endpunkts im Backend mit der SAMLResponse.
Diese wird im Backend ausgewertet und es erfolgt ein Redirect auf den Client mit dem Login code.
Mit dem Login code wird sein Request an das Backend gemacht und wenn der Code erfolreich geprüft wurde wird ein
Jwt Token mit den Benutzerdaten an den Client gesendet und er ist jetzt erfolgreich angemeldet.

## Parameters

Um die BayernId zu konfigurieren, gibt es in der application.yml folgenden Abschnitt:

```
ozgcloud:
    bayernid:
        authnMethods:  # Die möglichen Authentifizieungsmethoden
            Authega: "false"
            Benutzername: "true"
            eID: "false"
            eIDAS: "false"
            Diia: "false"
            Elster: "true"
            FINK: "false"
        requestedAttributeUrns: # Die von dem BayernId Portal zurückgegeben Informationen
            - "urn:oid:2.5.4.18"                    # Postkorb-Handle = die ID des Postfachs des Benutzers
            - "urn:oid:1.3.6.1.4.1.25484.494450.3"  # bereichsspezifisches Personenkennzeichen 2 ? eigentlichen ssPIN" (siehe Kapitel zur bPK) im Servicedokument 
            - "urn:oid:1.2.40.0.10.2.1.1.261.94"    # Vertrauensniveau (siehe Kapitel 6.2.3 Vertrauensniveau)
            - "urn:oid:1.3.6.1.4.1.25484.494450.2"  # AssertionProvedBy (siehe Kapitel 6.2.5 AssertionProvedBy 
            - "urn:oid:2.5.4.42"                    # Vorname
            - "urn:oid:2.5.4.4"                     # Nachname
            - "urn:oid:0.9.2342.19200300.100.1.3"   # Emailadresse
        redirect-url: "http://localhost:8082"       # Die öffentliche Adresse des Antragraum-Clients
spring:
  .
  .
  .
  security:
    saml2:
      relyingparty:
        registration:
          bayernid:
            entity-id: https://antragsraum.ozgcloud.de/                     # Die festgelegte entityId
            signing:
              credentials:
                - private-key-location: "classpath:bayernid-test-sign.key"  # Der private Key des Signging Zertifikats (! Nicht veröffenlichen)
                  certificate-location: "classpath:bayernid-test-sign.crt"  # Das Signging Zertifikat wie im Metadaten Dokument an Akdb gesendet 
            decryption:
              credentials:
                - private-key-location: "classpath:bayernid-test-enc.key"   # Der private Key des Encyption Zertifikats (! Nicht veröffenlichen)
                  certificate-location: "classpath:bayernid-test-enc.crt"   # Das Encyption Zertifikat wie im Metadaten Dokument an Akdb gesendet
            assertingparty:
              singlesignon:
                sign-request: true
              metadata-uri: "classpath:/metadata/bayernid-idp-infra.xml"    # Das idp Metadaten Dokument kann z.b. von https://infra-pre-id.bayernportal.de/idp geladen werden 
```

### Umgebungen

Es gibt folgendende BayernId Umgebungen:

* pre-a-id.bayernportal.de
* pre-b-id.bayernportal.de
* pre-c-id.bayernportal.de
* pre-d-id.bayernportal.de
* pre-e-id.bayernportal.de
* infra-pre-id.bayernportal.de -- wird for DEV verwendet
* pre-id.bayernportal.de
* id.bayernportal.de -- wird für PROD verwendet

Das Einspielen der MetaDaten auf DEV erledigt Akdb auf Kosten des Landes Bayern, auf PROD hingegen muss von mgm
bezahlt werden.

## Implementierung

Es wird das Spring Framework verwendet, um den Login zu implementieren.
Siehe [SAML 2.0 Login Overview](https://docs.spring.io/spring-security/reference/servlet/saml2/login/overview.html)

## Keycloak als Broker zwischen BayernID und OAuth

Da der Antragsraum Client die SPA-Anwendung in React ist, würde es Sinn machen OpenId als Authentifizierung zu
verwenden.
Keycloak ist in der Lage als SAML IDPs wie BayerId zu verwenden uns als Broker zwischen SAML und OpenId zu
funktionieren.

Aber da bei BayerId in der Authentifizierungsrequest angegeben werden muss welche Information man vom BayernId Portal
erhalten möchte, muss im Keycloak ein Plugin installiert werden, das diese Anfrage macht.

Es gibt ein solches Plugin
hier [landeshauptstadt-muenchen/bayernid-plugin](https://gitlab.opencode.de/landeshauptstadt-muenchen/bayernid-plugin)

Zum Zeitpunkt der Evaluierung war das Plugin aber nicht kompatibel zum verwendeten Keycloak.

Um das Plugin zu verwenden, müsste auch eine Anpassung an der Loginseite des passenden Realm im Keycloak gemacht werden.   



