/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.antragsraum.attachments;

import java.util.Arrays;

import org.springframework.stereotype.Component;
import org.springframework.util.unit.DataSize;
import org.springframework.web.multipart.MultipartFile;

import lombok.RequiredArgsConstructor;

@RequiredArgsConstructor
@Component
class FileValidator {

	private final FileProperties fileProperties;

	boolean isValid(MultipartFile file) {
		return fileSizeIsValid(file.getSize()) && fileContentTypeIsValid(file.getContentType());
	}

	boolean fileSizeIsValid(long fileSize) {
		return DataSize.ofBytes(fileSize).toBytes() <= fileProperties.getMaxFileSize().toBytes();
	}

	boolean fileContentTypeIsValid(String contentType) {
		if (contentType == null) {
			return false;
		}

		return !Arrays.asList(fileProperties.getBlockedContentTypes()).contains(contentType);
	}

}
