/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.antragsraum.command;

import jakarta.validation.constraints.Min;
import jakarta.validation.constraints.NotBlank;

import com.fasterxml.jackson.annotation.JsonInclude;

import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Builder;

@JsonInclude(JsonInclude.Include.NON_NULL)
@Builder()
record Command(
  @Schema(description = "The id of the command", name = "id", type = "string", example = "1258ad3f46811d04010f22ab")
  @NotBlank
  String id,
  @Schema(description = "The id of the NachrichtEvent in the InfoManager the command belongs to",
	name = "nachrichtEventId",
	type = "string",
	example = "60af924b4f1a2560298b4567"
  )
  String nachrichtEventId,
  @Schema(description = "The status of the command", name = "status", type = "String", example = "PENDING")
  String status,
  @Schema(description = "The date on which the command was created.")
  @Min(0)
  long createdAt,
  @Schema(description = "The date on which the command was completed.")
  Long finishedAt
) {

}
