/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.antragsraum.command;

import java.time.ZonedDateTime;

import org.mapstruct.Mapper;
import org.mapstruct.Mapping;

import de.ozgcloud.antragsraum.proxy.AntragraumproxyGrpcCommand;

@Mapper
interface CommandMapper {

	int IN_MILLISECONDS = 1000;

	@Mapping(target = "createdAt", expression = "java(convertCreatedAt(command.getCreatedAt()))")
	@Mapping(target = "finishedAt", expression = "java(convertFinishedAt(command.getFinishedAt()))")
	@Mapping(target = "nachrichtEventId", source = "nachrichtEventId")
	Command fromRestCommand(AntragraumproxyGrpcCommand command, String nachrichtEventId);

	default Long convertCreatedAt(String createdAt) {
		return createdAt != null
		  ? ZonedDateTime.parse(createdAt).toEpochSecond() * IN_MILLISECONDS
		  : ZonedDateTime.now().toEpochSecond() * IN_MILLISECONDS;
	}

	default Long convertFinishedAt(String finishedAt) {
		return (finishedAt == null || finishedAt.isEmpty())
		  ? null
		  : ZonedDateTime.parse(finishedAt).toEpochSecond() * IN_MILLISECONDS;
	}

}
