/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.antragsraum.events;

import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.stereotype.Component;
import org.springframework.web.client.RestClient;

import de.ozgcloud.antragsraum.WebConfiguration;
import de.ozgcloud.antragsraum.proxy.InfoGrpcInformationByIdResponse;
import de.ozgcloud.antragsraum.proxy.InfoGrpcInformationResponse;
import de.ozgcloud.common.errorhandling.TechnicalException;

@Component
class NachrichtEventRestClient {

	static final String INFORMATION_LIST_ENDPOINT = "api/v1/informations/{postfachId}";
	static final String INFORMATION_ENDPOINT = "api/v1/information/{id}";

	private final RestClient client;

	NachrichtEventRestClient(@Qualifier(WebConfiguration.INFO_MANAGER_REST_CLIENT) RestClient client) {
		this.client = client;
	}

	InfoGrpcInformationByIdResponse getNachrichtEventById(String id) {
		return get(INFORMATION_ENDPOINT, InfoGrpcInformationByIdResponse.class, id);
	}

	InfoGrpcInformationResponse getNachrichtEventsByPostfach(String postfachId) {
		return get(INFORMATION_LIST_ENDPOINT, InfoGrpcInformationResponse.class, postfachId);
	}

	<T> T get(String endpoint, Class<T> bodyType, Object... uriParams) {
		try {
			return client.get()
			  .uri(endpoint, uriParams)
			  .retrieve()
			  .toEntity(bodyType)
			  .getBody();
		} catch (Exception e) {
			throw new TechnicalException("Error retrieving data from grpc using restclient.", e);
		}
	}

}