/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.antragsraum.nachricht;

import org.springframework.hateoas.RepresentationModel;

import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Builder;
import lombok.EqualsAndHashCode;
import lombok.Getter;

@Builder
@Getter
@EqualsAndHashCode(callSuper = true)
class RueckfrageHeader extends RepresentationModel<RueckfrageHeader> {

	@Schema(description = "The title of the rueckfrage. This is the title of the Vorgang",
	  name = "title",
	  type = "string",
	  example = "Vorgang Hundesteuer Antrag"
	)
	String title;
	@Schema(description = "The header of the Rueckfrage sent by the clerk",
	  name = "nachrichtHeader",
	  type = "NachrichtHeader"
	)
	NachrichtHeader nachrichtHeader;
	@Schema(description = "Whether the Rueckfrage is accessible for current user or not",
	  name = "accessible",
	  type = "boolean"
	)
	boolean accessible;
	@Schema(description = "The trust level of the Rueckfrage sent by the clerk",
	  name = "trustLevel",
	  type = "string"
	)
	String trustLevel;
	@Schema(description = "Status of the Rueckfrage",
	  name = "status",
	  type = "String"
	)
	String status;

}
