/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.antragsraum.security;

import org.opensaml.xmlsec.algorithm.SignatureAlgorithm;

import lombok.NoArgsConstructor;
import lombok.NonNull;

@NoArgsConstructor
final class SHA256withRSAAndMGF1SignatureAlgorithm implements SignatureAlgorithm {

	static final String RSA_ALGORITHM_ID = "RSA";
	static final String RSA_SHA256_MGF1_ALGORITHM_URL = "http://www.w3.org/2007/05/xmldsig-more#sha256-rsa-MGF1";
	static final String RSA_SHA256_MGF1_ALGORITHM_ID = "SHA256withRSAandMGF1";
	static final String SHA256_ALGORITHM_ID = "SHA-256";

	@NonNull
	public String getKey() {
		return RSA_ALGORITHM_ID;
	}

	@NonNull
	public String getURI() {
		return RSA_SHA256_MGF1_ALGORITHM_URL;
	}

	@NonNull
	public AlgorithmType getType() {
		return AlgorithmType.Signature;
	}

	@NonNull
	public String getJCAAlgorithmID() {
		return RSA_SHA256_MGF1_ALGORITHM_ID;
	}

	@NonNull
	public String getDigest() {
		return SHA256_ALGORITHM_ID;
	}

}