/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.antragsraum.attachments;

import jakarta.validation.Validator;

import org.springframework.boot.test.mock.mockito.MockBean;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.ComponentScan;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.FilterType;
import org.springframework.scheduling.annotation.EnableAsync;
import org.springframework.validation.beanvalidation.LocalValidatorFactoryBean;
import org.springframework.web.client.RestClient;

import de.ozgcloud.antragsraum.WebConfiguration;
import de.ozgcloud.antragsraum.events.NachrichtEventService;

@EnableAsync
@ComponentScan(value = { "de.ozgcloud.antragsraum.attachments", "de.ozgcloud.antragsraum.common" },
  excludeFilters = @ComponentScan.Filter(type = FilterType.ASSIGNABLE_TYPE,
	classes = { FileControllerTestConfiguration.class, FileController.class, FileRemoteServiceTestConfiguration.class }))
@Configuration
public class FileRestClientTestConfiguration {

	@MockBean
	FileService fileService;

	@MockBean
	NachrichtEventService nachrichtEventService;

	@Bean
	public RestClient.Builder restClientBuilder() {
		return RestClient.builder().baseUrl(FileRestClientTest.ADDRESS);
	}

	@Bean(name = WebConfiguration.NACHRICHT_REST_CLIENT)
	RestClient fileRestClient() {
		return restClientBuilder().build();
	}

	@Bean
	public Validator defaultValidator() {
		return new LocalValidatorFactoryBean();
	}

	@MockBean
	VirusScannerClient virusScannerClient;

}
