/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.antragsraum.command;

import static org.mockito.Mockito.*;
import static org.springframework.test.web.servlet.request.MockMvcRequestBuilders.*;
import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.*;

import java.nio.charset.Charset;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.autoconfigure.web.servlet.AutoConfigureMockMvc;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.boot.test.mock.mockito.MockBean;
import org.springframework.boot.test.mock.mockito.SpyBean;
import org.springframework.http.MediaType;
import org.springframework.security.test.context.support.WithMockUser;
import org.springframework.test.context.junit.jupiter.SpringJUnitConfig;
import org.springframework.test.web.servlet.MockMvc;
import org.springframework.test.web.servlet.ResultActions;

import de.ozgcloud.antragsraum.common.TechnicalException;
import de.ozgcloud.antragsraum.events.NachrichtEventTestFactory;

@AutoConfigureMockMvc
@SpringBootTest(webEnvironment = SpringBootTest.WebEnvironment.MOCK)
@SpringJUnitConfig(classes = { CommandControllerTestConfiguration.class })
public class CommandControllerITCase {

	@SpyBean
	private CommandController commandController;

	@Autowired
	private MockMvc mockMvc;

	@MockBean
	private CommandService commandService;

	@Nested
	class TestGetCommand {

		@BeforeEach
		void init() {
			when(commandService.getCommand(CommandTestFactory.ID, NachrichtEventTestFactory.ID)).thenReturn(CommandTestFactory.create());
		}

		@Test
		@WithMockUser
		void shouldLoadCommand() throws Exception {
			performRequest()
			  .andExpect(status().isOk())
			  .andExpect(jsonPath("$['id']").value(CommandTestFactory.ID));
		}

		@Test
		void shouldNotLoadCommandUnauthorized() throws Exception {
			performRequest().andExpect(status().isUnauthorized());
		}

		@Test
		@WithMockUser
		void shouldHandleRuntimeExceptions() throws Exception {
			doThrow(RuntimeException.class).when(commandService).getCommand(CommandTestFactory.ID, NachrichtEventTestFactory.ID);

			performRequest().andExpect(status().isInternalServerError());
		}

		@Test
		@WithMockUser
		void shouldHandleTechnicalExceptions() throws Exception {
			doThrow(TechnicalException.class).when(commandService).getCommand(CommandTestFactory.ID, NachrichtEventTestFactory.ID);

			performRequest().andExpect(status().isInternalServerError());
		}

		ResultActions performRequest() throws Exception {
			return mockMvc.perform(
			  get(CommandController.PATH + "/command/" + CommandTestFactory.ID + "/" + NachrichtEventTestFactory.ID)
				.contentType(MediaType.APPLICATION_JSON).characterEncoding(Charset.defaultCharset()));
		}

	}

}