/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.antragsraum.nachricht;

import static org.assertj.core.api.Assertions.*;

import java.util.UUID;

import org.apache.http.entity.ContentType;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;

import de.ozgcloud.vorgang.grpc.binaryFile.GrpcBinaryFile;

class AttachmentMapperTest {

	static final String ID = UUID.randomUUID().toString();
	static final String CONTENT_TYPE = ContentType.APPLICATION_OCTET_STREAM.toString();
	static final long FILE_SIZE = 10;
	static final String FILE_NAME = "Testfile.zip";

	GrpcBinaryFile file = GrpcBinaryFile.newBuilder()
	  .setId(ID)
	  .setName(FILE_NAME)
	  .setSize(FILE_SIZE)
	  .setContentType(CONTENT_TYPE)
	  .build();

	@Nested
	class MapFromGrpcBinaryFile {

		@Test
		void shouldMapAttachment() {
			var res = AttachmentMapper.fromGrpcBinaryFile(file);

			assertThat(res).isNotNull();
		}

		@Test
		void shouldMapAttachmentId() {
			var res = AttachmentMapper.fromGrpcBinaryFile(file).id();

			assertThat(res).isEqualTo(ID);
		}

		@Test
		void shouldMapAttachmentName() {
			var res = AttachmentMapper.fromGrpcBinaryFile(file).fileName();

			assertThat(res).isEqualTo(FILE_NAME);
		}

		@Test
		void shouldMapAttachmentSize() {
			var res = AttachmentMapper.fromGrpcBinaryFile(file).fileSize();

			assertThat(res).isEqualTo(FILE_SIZE);
		}

		@Test
		void shouldMapAttachmentContentType() {
			var res = AttachmentMapper.fromGrpcBinaryFile(file).contentType();

			assertThat(res).isEqualTo(CONTENT_TYPE);
		}

	}

}