/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.antragsraum.nachricht;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.Mockito.*;

import java.util.List;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.extension.ExtendWith;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.Spy;
import org.mockito.junit.jupiter.MockitoExtension;

@ExtendWith(MockitoExtension.class)
class NachrichtenControllerTest {

	@Spy
	@InjectMocks
	private NachrichtenController nachrichtenController;

	@Mock
	private NachrichtenService nachrichtenService;

	@Nested
	class TestLoadingRueckfrageHeaders {

		@BeforeEach
		void init() {
			when(nachrichtenService.getRueckfrageHeadersOfPostfach(NachrichtTestFactory.POSTFACH_ID)).thenReturn(
			  List.of(RueckfrageTestFactory.createRueckfrageHeader()));
		}

		@Test
		void shouldLoadRueckfrageHeaders() {
			var result = nachrichtenController.getRueckfrageHeadersOfPostfach(NachrichtTestFactory.POSTFACH_ID);

			assertThat(result).hasSize(1);
		}

		@Test
		void shouldCallGetRueckfrageHeadersOfPostfach() {
			nachrichtenController.getRueckfrageHeadersOfPostfach(NachrichtTestFactory.POSTFACH_ID);

			verify(nachrichtenService).getRueckfrageHeadersOfPostfach(anyString());
		}

	}

	@Nested
	class TestLoadingRueckfrage {

		@BeforeEach
		void init() {
			when(nachrichtenService.getRueckfrage(NachrichtTestFactory.ID, NachrichtTestFactory.NACHRICHT_EVENT_ID)).thenReturn(
			  RueckfrageTestFactory.createRueckfrage());
		}

		@Test
		void shouldLoadRueckfrage() {
			var result = nachrichtenController.getRueckfrage(NachrichtTestFactory.ID, NachrichtTestFactory.NACHRICHT_EVENT_ID);

			assertThat(result).isNotNull();
		}

		@Test
		void shouldCallGetRueckfrageOfPostfach() {
			nachrichtenController.getRueckfrage(NachrichtTestFactory.ID, NachrichtTestFactory.NACHRICHT_EVENT_ID);

			verify(nachrichtenService).getRueckfrage(anyString(), anyString());
		}

	}

	@Nested
	class TestSendingAnswer {

		@Test
		void shouldCallService() {
			nachrichtenController.sendNachricht(ReplyNachrichtTestFactory.create());

			verify(nachrichtenService).sendRueckfrageAnswer(any(ReplyNachricht.class));
		}

	}

}