/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.antragsraum.nachricht;

import static de.ozgcloud.antragsraum.nachricht.AntragraumproxyGrpcRueckfrageTestFactory.*;
import static de.ozgcloud.antragsraum.nachricht.NachrichtenRestClient.*;
import static org.assertj.core.api.Assertions.*;
import static org.springframework.test.web.client.match.MockRestRequestMatchers.*;
import static org.springframework.test.web.client.response.MockRestResponseCreators.*;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.autoconfigure.web.client.RestClientTest;
import org.springframework.boot.test.web.client.MockServerRestClientCustomizer;
import org.springframework.http.MediaType;
import org.springframework.test.context.junit.jupiter.SpringJUnitConfig;
import org.springframework.test.web.client.MockRestServiceServer;
import org.springframework.web.client.RestClient;

import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;

@SpringJUnitConfig(classes = { NachrichtenRestClientTestConfiguration.class })
@RestClientTest(NachrichtenRestClient.class)
class NachrichtenRestClientTest {

	final static String ADDRESS = "http://localhost:8382/";
	private final static String TOKEN = "saml_token";

	private NachrichtenRestClient nachrichtenRestClient;

	@Autowired
	private RestClient.Builder restClientBuilder;

	@Autowired
	private MockServerRestClientCustomizer customizer;

	private MockRestServiceServer server;

	private final ObjectMapper objectMapper = new ObjectMapper();

	@Nested
	class TestSendingRequests {

		@Nested
		class TestRueckfrageAnswer {

			@BeforeEach
			void setup() throws JsonProcessingException {
				customizer.customize(restClientBuilder);
				server = customizer.getServer(restClientBuilder);
				server.expect(requestTo(ADDRESS + SEND_ANTWORT_URI))
				  .andRespond(withSuccess(objectMapper.writeValueAsString(createSendRueckfrageAnswerResponse()), MediaType.APPLICATION_JSON));
				nachrichtenRestClient = new NachrichtenRestClient(restClientBuilder.build());
			}

			@Test
			void shouldGetAnswerResponse() {
				var response = nachrichtenRestClient.answerRueckfrage(createRueckfrageAnswer(), TOKEN, ADDRESS);

				assertThat(response).isNotNull();
			}

		}

		@Nested
		class TestFindRueckfragen {

			@BeforeEach
			void setup() throws JsonProcessingException {
				customizer.customize(restClientBuilder);
				server = customizer.getServer(restClientBuilder);
				server.expect(requestTo(ADDRESS + GET_RUECKFRAGEN_URI))
				  .andRespond(withSuccess(objectMapper.writeValueAsString(createFindRueckfragenResponse()), MediaType.APPLICATION_JSON));
				nachrichtenRestClient = new NachrichtenRestClient(restClientBuilder.build());
			}

			@Test
			void shouldCallClientFindRueckfragen() {
				var response = nachrichtenRestClient.getFindRueckfragen(ReplyNachrichtTestFactory.ID, TOKEN, ADDRESS);

				assertThat(response).isNotNull();
			}

		}

		@Nested
		class TestGetRueckfrage {

			@BeforeEach
			void setup() throws JsonProcessingException {
				customizer.customize(restClientBuilder);
				server = customizer.getServer(restClientBuilder);
				server.expect(requestTo(ADDRESS + GET_RUECKFRAGE_URI))
				  .andRespond(withSuccess(objectMapper.writeValueAsString(createGetRueckfrageResponse()), MediaType.APPLICATION_JSON));
				nachrichtenRestClient = new NachrichtenRestClient(restClientBuilder.build());
			}

			@Test
			void shouldCallClientGetRueckfrage() {
				var response = nachrichtenRestClient.getGetRueckfrage(ReplyNachrichtTestFactory.ID, TOKEN, ADDRESS);

				assertThat(response).isNotNull();
			}

		}

	}

}