/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.antragsraum.nachricht;

import static org.assertj.core.api.Assertions.*;

import java.util.List;

import org.junit.jupiter.api.Test;

class RueckfrageHeaderMapperTest {

	private final List<NachrichtHeader> nachrichtHeaders = List.of(NachrichtTestFactory.createNachrichtHeader(),
	  NachrichtTestFactory.createNachrichtHeader());

	@Test
	void shouldHaveHeaders() {
		var headers = RueckfrageHeaderMapper.fromNachrichtHeaders(nachrichtHeaders);

		assertThat(headers).hasSize(2);
	}

	@Test
	void shouldMapClerkNachrichtHeader() {
		var headers = RueckfrageHeaderMapper.fromNachrichtHeaders(nachrichtHeaders);

		assertThat(headers.getFirst().getNachrichtHeader()).isNotNull();
		assertThat(headers.get(1).getNachrichtHeader()).isNotNull();
	}

	@Test
	void shouldMapVorgangId() {
		var headers = RueckfrageHeaderMapper.fromNachrichtHeaders(nachrichtHeaders);

		assertThat(headers.getFirst().getNachrichtHeader().id()).isEqualTo(NachrichtTestFactory.ID);
		assertThat(headers.get(1).getNachrichtHeader().id()).isEqualTo(NachrichtTestFactory.ID);
	}

	@Test
	void shouldMapVorgangName() {
		var headers = RueckfrageHeaderMapper.fromNachrichtHeaders(nachrichtHeaders);

		assertThat(headers.getFirst().getTitle()).isEqualTo(NachrichtTestFactory.VORGANG_TITLE);
		assertThat(headers.get(1).getTitle()).isEqualTo(NachrichtTestFactory.VORGANG_TITLE);
	}

	@Test
	void shouldMapAccessible() {
		var headers = RueckfrageHeaderMapper.fromNachrichtHeaders(nachrichtHeaders);

		assertThat(headers.getFirst().isAccessible()).isEqualTo(NachrichtTestFactory.ACCESSIBLE);
		assertThat(headers.get(1).isAccessible()).isEqualTo(NachrichtTestFactory.ACCESSIBLE);
	}

	@Test
	void shouldMapTrustLevel() {
		var headers = RueckfrageHeaderMapper.fromNachrichtHeaders(nachrichtHeaders);

		assertThat(headers.getFirst().getTrustLevel()).isEqualTo(NachrichtTestFactory.TRUST_LEVEL);
		assertThat(headers.get(1).getTrustLevel()).isEqualTo(NachrichtTestFactory.TRUST_LEVEL);
	}

	@Test
	void shouldMapStatus() {
		var headers = RueckfrageHeaderMapper.fromNachrichtHeaders(nachrichtHeaders);

		assertThat(headers.getFirst().getStatus()).isEqualTo(NachrichtTestFactory.STATUS);
		assertThat(headers.get(1).getStatus()).isEqualTo(NachrichtTestFactory.STATUS);
	}

}