/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.antragsraum.nachricht;

import static org.assertj.core.api.Assertions.*;

import org.junit.jupiter.api.Test;

class RueckfrageMapperTest {

	private final Nachricht nachricht = NachrichtTestFactory.createNachricht();

	@Test
	void shouldHaveRueckfrage() {
		var rueckfrage = RueckfrageMapper.fromNachricht(nachricht);

		assertThat(rueckfrage).isNotNull();
	}

	@Test
	void shouldMapClerkNachricht() {
		var rueckfrage = RueckfrageMapper.fromNachricht(nachricht);

		assertThat(rueckfrage.getNachricht()).isNotNull();
	}

	@Test
	void shouldMapVorgangId() {
		var rueckfrage = RueckfrageMapper.fromNachricht(nachricht);

		assertThat(rueckfrage.getNachricht().id()).isEqualTo(NachrichtTestFactory.ID);
	}

	@Test
	void shouldNotHaveReplyInNachricht() {
		var rueckfrage = RueckfrageMapper.fromNachricht(nachricht);

		assertThat(rueckfrage.getNachricht().replyNachrichten()).isNull();
	}

	@Test
	void shouldMapUserNachrichten() {
		var rueckfrage = RueckfrageMapper.fromNachricht(nachricht);

		assertThat(rueckfrage.getAntworten()).hasSize(1);
	}

	@Test
	void shouldMapVorgangName() {
		var rueckfrage = RueckfrageMapper.fromNachricht(nachricht);

		assertThat(rueckfrage.getTitle()).isEqualTo(NachrichtTestFactory.VORGANG_TITLE);
	}

	@Test
	void shouldMapAccessible() {
		var rueckfrage = RueckfrageMapper.fromNachricht(nachricht);

		assertThat(rueckfrage.isAccessible()).isEqualTo(NachrichtTestFactory.ACCESSIBLE);
	}

	@Test
	void shouldMapTrustLevel() {
		var rueckfrage = RueckfrageMapper.fromNachricht(nachricht);

		assertThat(rueckfrage.getTrustLevel()).isEqualTo(NachrichtTestFactory.TRUST_LEVEL);
	}

}