/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.antragsraum.security;

import static org.mockito.Mockito.*;

import java.io.IOException;

import jakarta.servlet.ServletException;
import jakarta.servlet.http.HttpServletRequest;
import jakarta.servlet.http.HttpServletResponse;

import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.extension.ExtendWith;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.Spy;
import org.mockito.junit.jupiter.MockitoExtension;
import org.springframework.security.core.Authentication;

@ExtendWith(MockitoExtension.class)
class AntragsraumLogoutSuccessHandlerTest {

	@Spy
	@InjectMocks
	private AntragsraumLogoutSuccessHandler antragsraumLogoutSuccessHandler;
	@Mock
	private InMemoryUserDetailService userDetailService;

	@Test
	void shouldCallLogout() throws ServletException, IOException {
		Authentication authentication = mock(Authentication.class);
		when(authentication.getPrincipal()).thenReturn(UserTestFactory.create());

		antragsraumLogoutSuccessHandler.onLogoutSuccess(mock(HttpServletRequest.class), mock(HttpServletResponse.class), authentication);

		verify(userDetailService).logout(any(User.class));
	}

	@Test
	void shouldNotCallLogout() throws ServletException, IOException {
		antragsraumLogoutSuccessHandler.onLogoutSuccess(mock(HttpServletRequest.class), mock(HttpServletResponse.class), mock(Authentication.class));

		verify(userDetailService, never()).logout(any(User.class));
	}

}