/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.antragsraum.security;

import static org.assertj.core.api.Assertions.*;

import java.time.ZoneId;
import java.time.ZonedDateTime;
import java.util.Base64;

import org.apache.commons.lang3.RandomStringUtils;
import org.assertj.core.data.Percentage;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.extension.ExtendWith;
import org.mockito.junit.jupiter.MockitoExtension;
import org.springframework.test.util.ReflectionTestUtils;

@ExtendWith(MockitoExtension.class)
class JwtTokenProviderTest {

	private static final String SECRET = RandomStringUtils.random(256);

	JwtTokenProvider provider = new JwtTokenProvider();

	@BeforeEach
	void setup() {
		ReflectionTestUtils.setField(provider, "jwtSecret", SECRET);
	}

	@Nested
	class TestJwtGeneration {

		@Test
		void shouldGenerateToken() {
			assertThat(provider.generate(UserTestFactory.create())).isNotNull();
		}

		@Test
		void shouldExpireIn30Min() {
			var jwt = provider.generate(UserTestFactory.create());
			long in30Min = ZonedDateTime.now(ZoneId.of("UTC")).plusMinutes(30L).toInstant().toEpochMilli() / 1000;
			var expireTimeStamp = getTokenExpireTimeStamp(jwt);

			assertThat(expireTimeStamp).isCloseTo(in30Min, Percentage.withPercentage(5));
		}

		private Long getTokenExpireTimeStamp(final String jwt) {
			var decoded = Base64.getDecoder().decode(jwt.split("\\.")[1]);
			var token = new String(decoded);
			var expIndex = token.indexOf("\"exp\":");
			return Long.valueOf(token.substring(expIndex + 6, expIndex + 16));
		}

	}

}